# Profiler: Profiling your model


> NOTE: This tutorial is still working in progress

In this tutorial, we will show:
1. how to profiling your model and check the elapsed time of each operation
2. profiling the cache hit rate




```python
import jittor as jt
```